@@ -3,20 +3,24 @@ package File::HomeDir::Darwin;
 # Basic implementation for the Dawin family of operating systems.
 # This includes (most prominently) Mac OS X.
 
-use 5.005;
+use 5.00503;
 use strict;
-use base 'File::HomeDir::Unix';
+use File::HomeDir::Unix ();
 use Carp ();
-use Cwd  ();
+use Cwd ();
 
-use vars qw{$VERSION};
+use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '0.69';
+	$VERSION = '0.81';
+	@ISA     = 'File::HomeDir::Unix';
 }
 
 # Load early if in a forking environment and we have
 # prefork, or at run-time if not.
-eval "use prefork 'Mac::Files'";
+SCOPE: {
+	local $@;
+	eval "use prefork 'Mac::Files'";
+}
 
 
 
@@ -135,10 +139,8 @@ sub users_data {
 # there's really no other good way to do it at this time, that i know of -- pudge
 sub _to_user {
 	my ($class, $path, $name) = @_;
-
 	my $my_home    = $class->my_home;
 	my $users_home = $class->users_home($name);
-
 	$path =~ s/^Q$my_home/$users_home/;
 	return $path;
 }
@@ -162,14 +164,13 @@ used via L<File::HomeDir>.
   use File::HomeDir;
   
   # Find directories for the current user
-  $home    = File::HomeDir->my_home;        # /Users/mylogin
-  $desktop = File::HomeDir->my_desktop;     # /Users/mylogin/Desktop
-  $docs    = File::HomeDir->my_documents;   # /Users/mylogin/Documents
-  $music   = File::HomeDir->my_music;       # /Users/mylogin/Music
-  $pics    = File::HomeDir->my_pictures;    # /Users/mylogin/Pictures
-  $videos  = File::HomeDir->my_videos;      # /Users/mylogin/Movies
-  $data    = File::HomeDir->my_data;        # /Users/mylogin/Library/Application Support
-   
+  $home    = File::HomeDir->my_home;      # /Users/mylogin
+  $desktop = File::HomeDir->my_desktop;   # /Users/mylogin/Desktop
+  $docs    = File::HomeDir->my_documents; # /Users/mylogin/Documents
+  $music   = File::HomeDir->my_music;     # /Users/mylogin/Music
+  $pics    = File::HomeDir->my_pictures;  # /Users/mylogin/Pictures
+  $videos  = File::HomeDir->my_videos;    # /Users/mylogin/Movies
+  $data    = File::HomeDir->my_data;      # /Users/mylogin/Library/Application Support
 
 =head1 TODO
 
