@@ -4,18 +4,23 @@ package File::HomeDir::MacOS9;
 # Provided mainly to provide legacy compatibility. May be removed at
 # a later date.
 
-use 5.005;
+use 5.00503;
 use strict;
+use File::HomeDir::Driver ();
 use Carp ();
 
-use vars qw{$VERSION};
+use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '0.69';
+	$VERSION = '0.81';
+	@ISA     = 'File::HomeDir::Driver';
 }
 
 # Load early if in a forking environment and we have
 # prefork, or at run-time if not.
-eval "use prefork 'Mac::Files'";
+SCOPE: {
+	local $@;
+	eval "use prefork 'Mac::Files'";
+}
 
 
 
@@ -35,10 +40,13 @@ sub my_home {
 	### DESPERATION SETS IN
 
 	# We could use the desktop
-	eval {
-		my $home = $class->my_desktop;
-		return $home if $home and -d $home;
-	};
+	SCOPE: {
+		local $@;
+		eval {
+			my $home = $class->my_desktop;
+			return $home if $home and -d $home;
+		};
+	}
 
 	# Desperation on any platform
 	SCOPE: {
